# Table of Contents

- [migrating-to-tbm-taxonomy-version-5-0-1-for-tech-categories](<./migrating-to-tbm-taxonomy-version-5-0-1-for-tech-categories.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Migrating to the TBM Taxonomy Version 5.0.1 for Tech Categories](<./Migrating-to-the-TBM-Taxonomy-Version-5.0.1-for-Tech-Categories.md>)
  - [Overview](<./Migrating-to-the-TBM-Taxonomy-Version-5.0.1-for-Tech-Categories/Overview.md>)
  - [Step 1: Update the Tech Category Hierarchy](<./Migrating-to-the-TBM-Taxonomy-Version-5.0.1-for-Tech-Categories/Step-1-Update-the-Tech-Category-Hierarchy.md>)
  - [Step 2: Rename Tech Categories](<./Migrating-to-the-TBM-Taxonomy-Version-5.0.1-for-Tech-Categories/Step-2-Rename-Tech-Categories.md>)
  - [Step 3: Import and Link Tech Categories](<./Migrating-to-the-TBM-Taxonomy-Version-5.0.1-for-Tech-Categories/Step-3-Import-and-Link-Tech-Categories.md>)
  - [Step 4: Update Relations to IT Components](<./Migrating-to-the-TBM-Taxonomy-Version-5.0.1-for-Tech-Categories/Step-4-Update-Relations-to-IT-Components.md>)
  - [Step 5: Clean Up Your Workspace](<./Migrating-to-the-TBM-Taxonomy-Version-5.0.1-for-Tech-Categories/Step-5-Clean-Up-Your-Workspace.md>)
